@@ -110,11 +110,13 @@ static const QString channelTypeToIconName( MixDevice::ChannelType type )
  * The ChannelType tells which kind of control the MixDevice is.
  */
 MixDevice::MixDevice(  Mixer* mixer, const QString& id, const QString& name, ChannelType type )
+    : _profControl(0)
 {
     init(mixer, id, name, channelTypeToIconName(type), (MixSet*)0);
 }
 
 MixDevice::MixDevice(  Mixer* mixer, const QString& id, const QString& name, const QString& iconName, MixSet* moveDestinationMixSet )
+    : _profControl(0)
 {
     init(mixer, id, name, iconName, moveDestinationMixSet);
 }
@@ -195,14 +197,9 @@ void MixDevice::increaseOrDecreaseVolume(bool decrease, Volume::VolumeTypeFlag v
 		if (debugme)
 		  kDebug() << ( decrease ? "decrease by " : "increase by " ) << inc ;
 
-		if (!decrease && isMuted())
+		if (isMuted())
 		{
-			// increasing from muted state: unmute and start with a low volume level
-			if (debugme)
-				kDebug() << "set all to " << inc << "muted old=" << isMuted();
-
 			setMuted(false);
-			volP.setAllVolumes(inc);
 		}
 		else
 		{
